Module traits

Module traits 

Repository Traits - Contracts for Entity Persistence

These traits define the contracts that entities and repositories must implement to work with the generic repository implementations.

Enums

RepositoryError
Repository error types

Traits

CrudRepository
Core CRUD repository trait
PartialUpdatable
Trait for entities that support partial updates via field map
PersistentEntity
Trait for entities that can be persisted.
SearchableRepository
Extended repository with search/filter capabilities
Versioned
Trait for entities with version/optimistic locking