UseCaseHooks

Trait UseCaseHooks 

pub trait UseCaseHooks<E: Send + Sync + 'static, DTO: Send + Sync + 'static>: Send + Sync {
    // Provided methods
    fn before_create<'life0, 'life1, 'async_trait>(
        &'life0 self,
        dto: &'life1 mut DTO,
    ) -> Pin<Box<dyn Future<Output = UseCaseResult<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait { ... }
    fn after_build<'life0, 'life1, 'async_trait>(
        &'life0 self,
        entity: &'life1 mut E,
    ) -> Pin<Box<dyn Future<Output = UseCaseResult<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait { ... }
    fn after_create<'life0, 'life1, 'async_trait>(
        &'life0 self,
        entity: &'life1 E,
    ) -> Pin<Box<dyn Future<Output = UseCaseResult<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait { ... }
    fn before_update<'life0, 'life1, 'life2, 'async_trait>(
        &'life0 self,
        entity: &'life1 E,
        dto: &'life2 mut DTO,
    ) -> Pin<Box<dyn Future<Output = UseCaseResult<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait { ... }
    fn after_update<'life0, 'life1, 'async_trait>(
        &'life0 self,
        entity: &'life1 E,
    ) -> Pin<Box<dyn Future<Output = UseCaseResult<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait { ... }
    fn before_delete<'life0, 'life1, 'async_trait>(
        &'life0 self,
        entity: &'life1 E,
    ) -> Pin<Box<dyn Future<Output = UseCaseResult<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait { ... }
    fn after_delete<'life0, 'life1, 'async_trait>(
        &'life0 self,
        id: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = UseCaseResult<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait { ... }
}
Extension points for every CRUD use case.

The default implementation (DefaultHooks) does nothing. Override individual methods in your custom decorator to inject behaviour.

Provided Methods

fn before_create<'life0, 'life1, 'async_trait>( &'life0 self, dto: &'life1 mut DTO, ) -> Pin<Box<dyn Future<Output = UseCaseResult<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Called before the entity is built from dto. Mutate the DTO if needed.

fn after_build<'life0, 'life1, 'async_trait>( &'life0 self, entity: &'life1 mut E, ) -> Pin<Box<dyn Future<Output = UseCaseResult<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Called after the entity is built, before it is persisted.

fn after_create<'life0, 'life1, 'async_trait>( &'life0 self, entity: &'life1 E, ) -> Pin<Box<dyn Future<Output = UseCaseResult<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Called after the entity is persisted.

fn before_update<'life0, 'life1, 'life2, 'async_trait>( &'life0 self, entity: &'life1 E, dto: &'life2 mut DTO, ) -> Pin<Box<dyn Future<Output = UseCaseResult<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait,

Called before an update is applied.

fn after_update<'life0, 'life1, 'async_trait>( &'life0 self, entity: &'life1 E, ) -> Pin<Box<dyn Future<Output = UseCaseResult<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Called after an update is persisted.

fn before_delete<'life0, 'life1, 'async_trait>( &'life0 self, entity: &'life1 E, ) -> Pin<Box<dyn Future<Output = UseCaseResult<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Called before a delete.

fn after_delete<'life0, 'life1, 'async_trait>( &'life0 self, id: &'life1 str, ) -> Pin<Box<dyn Future<Output = UseCaseResult<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Called after a delete.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<E: Send + Sync + 'static, DTO: Send + Sync + 'static> UseCaseHooks<E, DTO> for DefaultHooks<E, DTO>