pub struct RequiredUuid<E, F> { /* private fields */ }Expand description
Fails if a UUID string field is empty or not a valid v4 UUID.
Checks that the field is a non-empty string that can be parsed as a UUID.
Implementations