pub struct BackboneConfig {
pub app: AppConfig,
pub server: ServerConfig,
pub database: HashMap<String, DatabaseConfig>,
pub cache: HashMap<String, CacheConfig>,
pub modules: ModulesConfig,
pub logging: LoggingConfig,
pub monitoring: MonitoringConfig,
pub contexts: ContextsConfig,
pub features: FeaturesConfig,
pub security: SecurityConfig,
}Expand description
Main configuration struct for Backbone Framework
Contains all configuration sections needed to run a Backbone application. Supports loading from YAML, TOML, or JSON files with environment variable substitution.
Fields
app: AppConfigApplication metadata
server: ServerConfigServer configuration
database: HashMap<String, DatabaseConfig>Database configurations (keyed by name)
cache: HashMap<String, CacheConfig>Cache configurations (keyed by name)
modules: ModulesConfigModule configurations
logging: LoggingConfigLogging configuration
monitoring: MonitoringConfigMonitoring configuration
contexts: ContextsConfigCross-context communication
features: FeaturesConfigFeature flags
security: SecurityConfigSecurity settings
Implementations
Sourceimpl BackboneConfig
impl BackboneConfig
Sourcepub fn from_file<P: AsRef<Path>>(path: P) -> ConfigResult<Self>
pub fn from_file<P: AsRef<Path>>(path: P) -> ConfigResult<Self>
Sourcepub fn from_file_with_env<P: AsRef<Path>>(
base_path: P,
env: &str,
) -> ConfigResult<Self>
pub fn from_file_with_env<P: AsRef<Path>>( base_path: P, env: &str, ) -> ConfigResult<Self>
Load configuration with environment-specific overrides
Loads base config from {base_path} and merges with
{base_path}-{env}.{ext} if it exists.
Example
// Loads config/application.yml + config/application-development.yml
let config = BackboneConfig::from_file_with_env(
"config/application.yml",
"development"
)?;Sourcepub fn from_env() -> ConfigResult<Self>
pub fn from_env() -> ConfigResult<Self>
Load configuration from environment variables only
Uses default values and overrides with environment variables.
Sourcepub fn validate(&self) -> ConfigResult<()>
pub fn validate(&self) -> ConfigResult<()>
Validate the configuration
Returns an error if any critical configuration is invalid.
Sourcepub fn default_database(&self) -> Option<&DatabaseConfig>
pub fn default_database(&self) -> Option<&DatabaseConfig>
Get the default database configuration
Sourcepub fn get_database(&self, name: &str) -> Option<&DatabaseConfig>
pub fn get_database(&self, name: &str) -> Option<&DatabaseConfig>
Get a database configuration by name
Sourcepub fn default_cache(&self) -> Option<&CacheConfig>
pub fn default_cache(&self) -> Option<&CacheConfig>
Get the default cache configuration
Sourcepub fn get_cache(&self, name: &str) -> Option<&CacheConfig>
pub fn get_cache(&self, name: &str) -> Option<&CacheConfig>
Get a cache configuration by name
Sourcepub fn is_module_enabled(&self, module_name: &str) -> bool
pub fn is_module_enabled(&self, module_name: &str) -> bool
Check if a module is enabled
Sourcepub fn environment(&self) -> &Environment
pub fn environment(&self) -> &Environment
Get the current environment
Sourcepub fn is_production(&self) -> bool
pub fn is_production(&self) -> bool
Check if running in production
Sourcepub fn is_development(&self) -> bool
pub fn is_development(&self) -> bool
Check if running in development