pub struct FlowExecutor<H> {
pub handler: Arc<H>,
}Expand description
Generic executor shell — holds the handler, provides cancel/fail helpers.
Generated files wrap this with a newtype and add the unique execute_step():
ⓘ
pub struct OrderProcessingFlowExecutor<H: OrderProcessingStepHandler>(FlowExecutor<H>);
impl<H: OrderProcessingStepHandler> OrderProcessingFlowExecutor<H> {
pub fn new(handler: Arc<H>) -> Self { Self(FlowExecutor::new(handler)) }
pub fn handler(&self) -> &Arc<H> { &self.0.handler }
pub async fn execute_step(&self, instance: &mut OrderProcessingFlowInstance)
-> Result<(), FlowError> { /* unique dispatch */ }
pub async fn start(&self, id: impl Into<String>)
-> Result<OrderProcessingFlowInstance, FlowError> { self.0.start(id) }
pub async fn run(&self, instance: &mut OrderProcessingFlowInstance)
-> Result<(), FlowError> {
while !instance.is_complete() && instance.status != FlowStatus::Waiting {
self.execute_step(instance).await?;
}
Ok(())
}
pub fn cancel(&self, instance: &mut OrderProcessingFlowInstance) {
self.0.cancel(instance);
}
pub fn fail(&self, instance: &mut OrderProcessingFlowInstance, error: impl Into<String>) {
self.0.fail(instance, error);
}
}Fields
handler: Arc<H>Implementations
Sourceimpl<H: Send + Sync + 'static> FlowExecutor<H>
impl<H: Send + Sync + 'static> FlowExecutor<H>
pub fn new(handler: Arc<H>) -> Self
Sourcepub fn start<S>(&self, id: impl Into<String>, first_step: S) -> FlowInstance<S>
pub fn start<S>(&self, id: impl Into<String>, first_step: S) -> FlowInstance<S>
Start a new flow instance at a given step.
Sourcepub fn cancel<S>(&self, instance: &mut FlowInstance<S>)
pub fn cancel<S>(&self, instance: &mut FlowInstance<S>)
Cancel the flow instance.
Sourcepub fn fail<S>(&self, instance: &mut FlowInstance<S>, error: impl Into<String>)
pub fn fail<S>(&self, instance: &mut FlowInstance<S>, error: impl Into<String>)
Mark the flow instance as failed with a message.