pub struct EventBridge<External, Internal, A>{ /* private fields */ }Expand description
Bridges domain events from module A into module B by adapting and re-publishing.
Wire this at startup to translate event streams across bounded context boundaries.
Implementations
Sourceimpl<External, Internal, A> EventBridge<External, Internal, A>
impl<External, Internal, A> EventBridge<External, Internal, A>